Documentation
¶
Overview ¶
+k8s:deepcopy-gen=package Package v1alpha1 is the v1alpha1 version of the prometheusservice.services.k8s.aws API. +groupName=prometheusservice.services.k8s.aws
Index ¶
- Variables
- type AlertManagerDefinition
- type AlertManagerDefinitionDescription
- type AlertManagerDefinitionList
- type AlertManagerDefinitionSpec
- type AlertManagerDefinitionStatus
- type AlertManagerDefinitionStatusCode
- type AlertManagerDefinitionStatus_SDK
- type AmpConfiguration
- type LoggingConfiguration
- type LoggingConfigurationList
- type LoggingConfigurationMetadata
- type LoggingConfigurationSpec
- type LoggingConfigurationStatus
- type LoggingConfigurationStatusCode
- type LoggingConfigurationStatus_SDK
- type RuleGroupsNamespace
- type RuleGroupsNamespaceDescription
- type RuleGroupsNamespaceList
- type RuleGroupsNamespaceSpec
- type RuleGroupsNamespaceStatus
- type RuleGroupsNamespaceStatusCode
- type RuleGroupsNamespaceStatus_SDK
- type RuleGroupsNamespaceSummary
- type ScraperDescription
- type ScraperStatusCode
- type ScraperSummary
- type ValidationExceptionField
- type ValidationExceptionReason
- type Workspace
- type WorkspaceDescription
- type WorkspaceList
- type WorkspaceSpec
- type WorkspaceStatus
- type WorkspaceStatusCode
- type WorkspaceStatus_SDK
- type WorkspaceSummary
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is the API Group Version used to register the objects GroupVersion = schema.GroupVersion{Group: "prometheusservice.services.k8s.aws", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type AlertManagerDefinition ¶ added in v0.0.3
type AlertManagerDefinition struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec AlertManagerDefinitionSpec `json:"spec,omitempty"`
Status AlertManagerDefinitionStatus `json:"status,omitempty"`
}
AlertManagerDefinition is the Schema for the AlertManagerDefinitions API +kubebuilder:object:root=true +kubebuilder:subresource:status +kubebuilder:printcolumn:name="WORKSPACE-ID",type=string,priority=0,JSONPath=`.spec.workspaceID`
func (*AlertManagerDefinition) DeepCopy ¶ added in v0.0.3
func (in *AlertManagerDefinition) DeepCopy() *AlertManagerDefinition
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlertManagerDefinition.
func (*AlertManagerDefinition) DeepCopyInto ¶ added in v0.0.3
func (in *AlertManagerDefinition) DeepCopyInto(out *AlertManagerDefinition)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AlertManagerDefinition) DeepCopyObject ¶ added in v0.0.3
func (in *AlertManagerDefinition) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AlertManagerDefinitionDescription ¶
type AlertManagerDefinitionDescription struct {
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
// The base-64 encoded blob that is alert manager definition.
//
// For details about the alert manager definition, see AlertManagedDefinitionData
// (https://docs.aws.amazon.com/prometheus/latest/APIReference/yaml-AlertManagerDefinitionData.html).
Data []byte `json:"data,omitempty"`
ModifiedAt *metav1.Time `json:"modifiedAt,omitempty"`
// The status of the alert manager.
Status *AlertManagerDefinitionStatus_SDK `json:"status,omitempty"`
}
The details of an alert manager definition. It is the configuration for the alert manager, including information about receivers for routing alerts.
func (*AlertManagerDefinitionDescription) DeepCopy ¶
func (in *AlertManagerDefinitionDescription) DeepCopy() *AlertManagerDefinitionDescription
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlertManagerDefinitionDescription.
func (*AlertManagerDefinitionDescription) DeepCopyInto ¶
func (in *AlertManagerDefinitionDescription) DeepCopyInto(out *AlertManagerDefinitionDescription)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AlertManagerDefinitionList ¶ added in v0.0.3
type AlertManagerDefinitionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []AlertManagerDefinition `json:"items"`
}
AlertManagerDefinitionList contains a list of AlertManagerDefinition +kubebuilder:object:root=true
func (*AlertManagerDefinitionList) DeepCopy ¶ added in v0.0.3
func (in *AlertManagerDefinitionList) DeepCopy() *AlertManagerDefinitionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlertManagerDefinitionList.
func (*AlertManagerDefinitionList) DeepCopyInto ¶ added in v0.0.3
func (in *AlertManagerDefinitionList) DeepCopyInto(out *AlertManagerDefinitionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AlertManagerDefinitionList) DeepCopyObject ¶ added in v0.0.3
func (in *AlertManagerDefinitionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AlertManagerDefinitionSpec ¶ added in v0.0.3
type AlertManagerDefinitionSpec struct {
// The ID of the workspace to add the alert manager definition to.
//
// Regex Pattern: `[0-9A-Za-z][-.0-9A-Z_a-z]*`
// +kubebuilder:validation:XValidation:rule="self == oldSelf",message="Value is immutable once set"
WorkspaceID *string `json:"workspaceID,omitempty"`
WorkspaceRef *ackv1alpha1.AWSResourceReferenceWrapper `json:"workspaceRef,omitempty"`
// +kubebuilder:validation:Required
Configuration *string `json:"configuration"`
}
AlertManagerDefinitionSpec defines the desired state of AlertManagerDefinition.
func (*AlertManagerDefinitionSpec) DeepCopy ¶ added in v0.0.3
func (in *AlertManagerDefinitionSpec) DeepCopy() *AlertManagerDefinitionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlertManagerDefinitionSpec.
func (*AlertManagerDefinitionSpec) DeepCopyInto ¶ added in v0.0.3
func (in *AlertManagerDefinitionSpec) DeepCopyInto(out *AlertManagerDefinitionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AlertManagerDefinitionStatus ¶ added in v0.0.2
type AlertManagerDefinitionStatus struct {
// All CRs managed by ACK have a common `Status.ACKResourceMetadata` member
// that is used to contain resource sync state, account ownership,
// constructed ARN for the resource
// +kubebuilder:validation:Optional
ACKResourceMetadata *ackv1alpha1.ResourceMetadata `json:"ackResourceMetadata"`
// All CRs managed by ACK have a common `Status.Conditions` member that
// contains a collection of `ackv1alpha1.Condition` objects that describe
// the various terminal states of the CR and its backend AWS service API
// resource
// +kubebuilder:validation:Optional
Conditions []*ackv1alpha1.Condition `json:"conditions"`
// The current status of the alert manager.
// +kubebuilder:validation:Optional
StatusCode *string `json:"statusCode,omitempty"`
// If there is a failure, the reason for the failure.
// +kubebuilder:validation:Optional
StatusReason *string `json:"statusReason,omitempty"`
}
AlertManagerDefinitionStatus defines the observed state of AlertManagerDefinition
func (*AlertManagerDefinitionStatus) DeepCopy ¶ added in v0.0.2
func (in *AlertManagerDefinitionStatus) DeepCopy() *AlertManagerDefinitionStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlertManagerDefinitionStatus.
func (*AlertManagerDefinitionStatus) DeepCopyInto ¶ added in v0.0.2
func (in *AlertManagerDefinitionStatus) DeepCopyInto(out *AlertManagerDefinitionStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AlertManagerDefinitionStatusCode ¶
type AlertManagerDefinitionStatusCode string
const ( AlertManagerDefinitionStatusCode_CREATING AlertManagerDefinitionStatusCode = "CREATING" AlertManagerDefinitionStatusCode_ACTIVE AlertManagerDefinitionStatusCode = "ACTIVE" AlertManagerDefinitionStatusCode_UPDATING AlertManagerDefinitionStatusCode = "UPDATING" AlertManagerDefinitionStatusCode_DELETING AlertManagerDefinitionStatusCode = "DELETING" AlertManagerDefinitionStatusCode_CREATION_FAILED AlertManagerDefinitionStatusCode = "CREATION_FAILED" AlertManagerDefinitionStatusCode_UPDATE_FAILED AlertManagerDefinitionStatusCode = "UPDATE_FAILED" )
type AlertManagerDefinitionStatus_SDK ¶ added in v0.0.3
type AlertManagerDefinitionStatus_SDK struct {
// State of an AlertManagerDefinition.
StatusCode *string `json:"statusCode,omitempty"`
StatusReason *string `json:"statusReason,omitempty"`
}
The status of the alert manager.
func (*AlertManagerDefinitionStatus_SDK) DeepCopy ¶ added in v0.0.3
func (in *AlertManagerDefinitionStatus_SDK) DeepCopy() *AlertManagerDefinitionStatus_SDK
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AlertManagerDefinitionStatus_SDK.
func (*AlertManagerDefinitionStatus_SDK) DeepCopyInto ¶ added in v0.0.3
func (in *AlertManagerDefinitionStatus_SDK) DeepCopyInto(out *AlertManagerDefinitionStatus_SDK)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type AmpConfiguration ¶ added in v1.2.18
type AmpConfiguration struct {
// An ARN identifying a Workspace.
WorkspaceARN *string `json:"workspaceARN,omitempty"`
}
The AmpConfiguration structure defines the Amazon Managed Service for Prometheus instance a scraper should send metrics to.
func (*AmpConfiguration) DeepCopy ¶ added in v1.2.18
func (in *AmpConfiguration) DeepCopy() *AmpConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AmpConfiguration.
func (*AmpConfiguration) DeepCopyInto ¶ added in v1.2.18
func (in *AmpConfiguration) DeepCopyInto(out *AmpConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoggingConfiguration ¶ added in v1.2.0
type LoggingConfiguration struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec LoggingConfigurationSpec `json:"spec,omitempty"`
Status LoggingConfigurationStatus `json:"status,omitempty"`
}
LoggingConfiguration is the Schema for the LoggingConfigurations API +kubebuilder:object:root=true +kubebuilder:subresource:status +kubebuilder:printcolumn:name="LOG-GROUP-ARN",type=string,priority=0,JSONPath=`.spec.logGroupARN` +kubebuilder:printcolumn:name="WORKSPACE-ID",type=string,priority=0,JSONPath=`.spec.workspaceID`
func (*LoggingConfiguration) DeepCopy ¶ added in v1.2.0
func (in *LoggingConfiguration) DeepCopy() *LoggingConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingConfiguration.
func (*LoggingConfiguration) DeepCopyInto ¶ added in v1.2.0
func (in *LoggingConfiguration) DeepCopyInto(out *LoggingConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LoggingConfiguration) DeepCopyObject ¶ added in v1.2.0
func (in *LoggingConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LoggingConfigurationList ¶ added in v1.2.0
type LoggingConfigurationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []LoggingConfiguration `json:"items"`
}
LoggingConfigurationList contains a list of LoggingConfiguration +kubebuilder:object:root=true
func (*LoggingConfigurationList) DeepCopy ¶ added in v1.2.0
func (in *LoggingConfigurationList) DeepCopy() *LoggingConfigurationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingConfigurationList.
func (*LoggingConfigurationList) DeepCopyInto ¶ added in v1.2.0
func (in *LoggingConfigurationList) DeepCopyInto(out *LoggingConfigurationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LoggingConfigurationList) DeepCopyObject ¶ added in v1.2.0
func (in *LoggingConfigurationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LoggingConfigurationMetadata ¶ added in v0.1.2
type LoggingConfigurationMetadata struct {
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
LogGroupARN *string `json:"logGroupARN,omitempty"`
ModifiedAt *metav1.Time `json:"modifiedAt,omitempty"`
// The status of the logging configuration.
Status *LoggingConfigurationStatus_SDK `json:"status,omitempty"`
// A workspace ID.
Workspace *string `json:"workspace,omitempty"`
}
Contains information about the logging configuration for the workspace.
func (*LoggingConfigurationMetadata) DeepCopy ¶ added in v0.1.2
func (in *LoggingConfigurationMetadata) DeepCopy() *LoggingConfigurationMetadata
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingConfigurationMetadata.
func (*LoggingConfigurationMetadata) DeepCopyInto ¶ added in v0.1.2
func (in *LoggingConfigurationMetadata) DeepCopyInto(out *LoggingConfigurationMetadata)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoggingConfigurationSpec ¶ added in v1.2.0
type LoggingConfigurationSpec struct {
// The ARN of the CloudWatch log group to which the vended log data will be
// published. This log group must exist prior to calling this operation.
//
// Regex Pattern: `^arn:aws[a-z0-9-]*:logs:[a-z0-9-]+:\d{12}:log-group:[A-Za-z0-9\.\-\_\#/]{1,512}\:\*$`
// +kubebuilder:validation:Required
LogGroupARN *string `json:"logGroupARN"`
// The ID of the workspace to create the logging configuration for.
//
// Regex Pattern: `[0-9A-Za-z][-.0-9A-Z_a-z]*`
// +kubebuilder:validation:XValidation:rule="self == oldSelf",message="Value is immutable once set"
WorkspaceID *string `json:"workspaceID,omitempty"`
WorkspaceRef *ackv1alpha1.AWSResourceReferenceWrapper `json:"workspaceRef,omitempty"`
}
LoggingConfigurationSpec defines the desired state of LoggingConfiguration.
func (*LoggingConfigurationSpec) DeepCopy ¶ added in v1.2.0
func (in *LoggingConfigurationSpec) DeepCopy() *LoggingConfigurationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingConfigurationSpec.
func (*LoggingConfigurationSpec) DeepCopyInto ¶ added in v1.2.0
func (in *LoggingConfigurationSpec) DeepCopyInto(out *LoggingConfigurationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoggingConfigurationStatus ¶ added in v0.1.2
type LoggingConfigurationStatus struct {
// All CRs managed by ACK have a common `Status.ACKResourceMetadata` member
// that is used to contain resource sync state, account ownership,
// constructed ARN for the resource
// +kubebuilder:validation:Optional
ACKResourceMetadata *ackv1alpha1.ResourceMetadata `json:"ackResourceMetadata"`
// All CRs managed by ACK have a common `Status.Conditions` member that
// contains a collection of `ackv1alpha1.Condition` objects that describe
// the various terminal states of the CR and its backend AWS service API
// resource
// +kubebuilder:validation:Optional
Conditions []*ackv1alpha1.Condition `json:"conditions"`
// The current status of the logging configuration.
// +kubebuilder:validation:Optional
StatusCode *string `json:"statusCode,omitempty"`
// If failed, the reason for the failure.
// +kubebuilder:validation:Optional
StatusReason *string `json:"statusReason,omitempty"`
}
LoggingConfigurationStatus defines the observed state of LoggingConfiguration
func (*LoggingConfigurationStatus) DeepCopy ¶ added in v0.1.2
func (in *LoggingConfigurationStatus) DeepCopy() *LoggingConfigurationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingConfigurationStatus.
func (*LoggingConfigurationStatus) DeepCopyInto ¶ added in v0.1.2
func (in *LoggingConfigurationStatus) DeepCopyInto(out *LoggingConfigurationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LoggingConfigurationStatusCode ¶ added in v0.1.2
type LoggingConfigurationStatusCode string
const ( LoggingConfigurationStatusCode_CREATING LoggingConfigurationStatusCode = "CREATING" LoggingConfigurationStatusCode_ACTIVE LoggingConfigurationStatusCode = "ACTIVE" LoggingConfigurationStatusCode_UPDATING LoggingConfigurationStatusCode = "UPDATING" LoggingConfigurationStatusCode_DELETING LoggingConfigurationStatusCode = "DELETING" LoggingConfigurationStatusCode_CREATION_FAILED LoggingConfigurationStatusCode = "CREATION_FAILED" LoggingConfigurationStatusCode_UPDATE_FAILED LoggingConfigurationStatusCode = "UPDATE_FAILED" )
type LoggingConfigurationStatus_SDK ¶ added in v1.2.0
type LoggingConfigurationStatus_SDK struct {
// State of a logging configuration.
StatusCode *string `json:"statusCode,omitempty"`
StatusReason *string `json:"statusReason,omitempty"`
}
The status of the logging configuration.
func (*LoggingConfigurationStatus_SDK) DeepCopy ¶ added in v1.2.0
func (in *LoggingConfigurationStatus_SDK) DeepCopy() *LoggingConfigurationStatus_SDK
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LoggingConfigurationStatus_SDK.
func (*LoggingConfigurationStatus_SDK) DeepCopyInto ¶ added in v1.2.0
func (in *LoggingConfigurationStatus_SDK) DeepCopyInto(out *LoggingConfigurationStatus_SDK)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RuleGroupsNamespace ¶ added in v0.0.2
type RuleGroupsNamespace struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec RuleGroupsNamespaceSpec `json:"spec,omitempty"`
Status RuleGroupsNamespaceStatus `json:"status,omitempty"`
}
RuleGroupsNamespace is the Schema for the RuleGroupsNamespaces API +kubebuilder:object:root=true +kubebuilder:subresource:status +kubebuilder:printcolumn:name="WORKSPACE-ID",type=string,priority=0,JSONPath=`.spec.workspaceID` +kubebuilder:resource:shortName=rgn
func (*RuleGroupsNamespace) DeepCopy ¶ added in v0.0.2
func (in *RuleGroupsNamespace) DeepCopy() *RuleGroupsNamespace
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RuleGroupsNamespace.
func (*RuleGroupsNamespace) DeepCopyInto ¶ added in v0.0.2
func (in *RuleGroupsNamespace) DeepCopyInto(out *RuleGroupsNamespace)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RuleGroupsNamespace) DeepCopyObject ¶ added in v0.0.2
func (in *RuleGroupsNamespace) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RuleGroupsNamespaceDescription ¶
type RuleGroupsNamespaceDescription struct {
// An ARN identifying a rule groups namespace.
ARN *string `json:"arn,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
// The rule groups namespace data.
Data []byte `json:"data,omitempty"`
ModifiedAt *metav1.Time `json:"modifiedAt,omitempty"`
// The name of the namespace that the rule group belong to.
Name *string `json:"name,omitempty"`
// The status information about a rule groups namespace.
Status *RuleGroupsNamespaceStatus_SDK `json:"status,omitempty"`
// A tag associated with a resource.
Tags map[string]*string `json:"tags,omitempty"`
}
The details about one rule groups namespace.
func (*RuleGroupsNamespaceDescription) DeepCopy ¶
func (in *RuleGroupsNamespaceDescription) DeepCopy() *RuleGroupsNamespaceDescription
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RuleGroupsNamespaceDescription.
func (*RuleGroupsNamespaceDescription) DeepCopyInto ¶
func (in *RuleGroupsNamespaceDescription) DeepCopyInto(out *RuleGroupsNamespaceDescription)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RuleGroupsNamespaceList ¶ added in v0.0.2
type RuleGroupsNamespaceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []RuleGroupsNamespace `json:"items"`
}
RuleGroupsNamespaceList contains a list of RuleGroupsNamespace +kubebuilder:object:root=true
func (*RuleGroupsNamespaceList) DeepCopy ¶ added in v0.0.2
func (in *RuleGroupsNamespaceList) DeepCopy() *RuleGroupsNamespaceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RuleGroupsNamespaceList.
func (*RuleGroupsNamespaceList) DeepCopyInto ¶ added in v0.0.2
func (in *RuleGroupsNamespaceList) DeepCopyInto(out *RuleGroupsNamespaceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RuleGroupsNamespaceList) DeepCopyObject ¶ added in v0.0.2
func (in *RuleGroupsNamespaceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RuleGroupsNamespaceSpec ¶ added in v0.0.2
type RuleGroupsNamespaceSpec struct {
// The name for the new rule groups namespace.
//
// Regex Pattern: `[0-9A-Za-z][-.0-9A-Z_a-z]*`
// +kubebuilder:validation:XValidation:rule="self == oldSelf",message="Value is immutable once set"
// +kubebuilder:validation:Required
Name *string `json:"name"`
// The list of tag keys and values to associate with the rule groups namespace.
Tags map[string]*string `json:"tags,omitempty"`
// The ID of the workspace to add the rule groups namespace.
//
// Regex Pattern: `[0-9A-Za-z][-.0-9A-Z_a-z]*`
// +kubebuilder:validation:XValidation:rule="self == oldSelf",message="Value is immutable once set"
WorkspaceID *string `json:"workspaceID,omitempty"`
WorkspaceRef *ackv1alpha1.AWSResourceReferenceWrapper `json:"workspaceRef,omitempty"`
// +kubebuilder:validation:Required
Configuration *string `json:"configuration"`
}
RuleGroupsNamespaceSpec defines the desired state of RuleGroupsNamespace.
func (*RuleGroupsNamespaceSpec) DeepCopy ¶ added in v0.0.2
func (in *RuleGroupsNamespaceSpec) DeepCopy() *RuleGroupsNamespaceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RuleGroupsNamespaceSpec.
func (*RuleGroupsNamespaceSpec) DeepCopyInto ¶ added in v0.0.2
func (in *RuleGroupsNamespaceSpec) DeepCopyInto(out *RuleGroupsNamespaceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RuleGroupsNamespaceStatus ¶ added in v0.0.2
type RuleGroupsNamespaceStatus struct {
// All CRs managed by ACK have a common `Status.ACKResourceMetadata` member
// that is used to contain resource sync state, account ownership,
// constructed ARN for the resource
// +kubebuilder:validation:Optional
ACKResourceMetadata *ackv1alpha1.ResourceMetadata `json:"ackResourceMetadata"`
// All CRs managed by ACK have a common `Status.Conditions` member that
// contains a collection of `ackv1alpha1.Condition` objects that describe
// the various terminal states of the CR and its backend AWS service API
// resource
// +kubebuilder:validation:Optional
Conditions []*ackv1alpha1.Condition `json:"conditions"`
// A structure that returns the current status of the rule groups namespace.
// +kubebuilder:validation:Optional
Status *RuleGroupsNamespaceStatus_SDK `json:"status,omitempty"`
}
RuleGroupsNamespaceStatus defines the observed state of RuleGroupsNamespace
func (*RuleGroupsNamespaceStatus) DeepCopy ¶ added in v0.0.2
func (in *RuleGroupsNamespaceStatus) DeepCopy() *RuleGroupsNamespaceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RuleGroupsNamespaceStatus.
func (*RuleGroupsNamespaceStatus) DeepCopyInto ¶ added in v0.0.2
func (in *RuleGroupsNamespaceStatus) DeepCopyInto(out *RuleGroupsNamespaceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RuleGroupsNamespaceStatusCode ¶
type RuleGroupsNamespaceStatusCode string
const ( RuleGroupsNamespaceStatusCode_CREATING RuleGroupsNamespaceStatusCode = "CREATING" RuleGroupsNamespaceStatusCode_ACTIVE RuleGroupsNamespaceStatusCode = "ACTIVE" RuleGroupsNamespaceStatusCode_UPDATING RuleGroupsNamespaceStatusCode = "UPDATING" RuleGroupsNamespaceStatusCode_DELETING RuleGroupsNamespaceStatusCode = "DELETING" RuleGroupsNamespaceStatusCode_CREATION_FAILED RuleGroupsNamespaceStatusCode = "CREATION_FAILED" RuleGroupsNamespaceStatusCode_UPDATE_FAILED RuleGroupsNamespaceStatusCode = "UPDATE_FAILED" )
type RuleGroupsNamespaceStatus_SDK ¶ added in v0.0.2
type RuleGroupsNamespaceStatus_SDK struct {
// State of a namespace.
StatusCode *string `json:"statusCode,omitempty"`
StatusReason *string `json:"statusReason,omitempty"`
}
The status information about a rule groups namespace.
func (*RuleGroupsNamespaceStatus_SDK) DeepCopy ¶ added in v0.0.2
func (in *RuleGroupsNamespaceStatus_SDK) DeepCopy() *RuleGroupsNamespaceStatus_SDK
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RuleGroupsNamespaceStatus_SDK.
func (*RuleGroupsNamespaceStatus_SDK) DeepCopyInto ¶ added in v0.0.2
func (in *RuleGroupsNamespaceStatus_SDK) DeepCopyInto(out *RuleGroupsNamespaceStatus_SDK)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RuleGroupsNamespaceSummary ¶
type RuleGroupsNamespaceSummary struct {
// An ARN identifying a rule groups namespace.
ARN *string `json:"arn,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
ModifiedAt *metav1.Time `json:"modifiedAt,omitempty"`
// The name of the namespace that the rule group belong to.
Name *string `json:"name,omitempty"`
// The status information about a rule groups namespace.
Status *RuleGroupsNamespaceStatus_SDK `json:"status,omitempty"`
// A tag associated with a resource.
Tags map[string]*string `json:"tags,omitempty"`
}
The high-level information about a rule groups namespace. To retrieve more information, use DescribeRuleGroupsNamespace.
func (*RuleGroupsNamespaceSummary) DeepCopy ¶
func (in *RuleGroupsNamespaceSummary) DeepCopy() *RuleGroupsNamespaceSummary
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RuleGroupsNamespaceSummary.
func (*RuleGroupsNamespaceSummary) DeepCopyInto ¶
func (in *RuleGroupsNamespaceSummary) DeepCopyInto(out *RuleGroupsNamespaceSummary)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ScraperDescription ¶ added in v1.2.18
type ScraperDescription struct {
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
LastModifiedAt *metav1.Time `json:"lastModifiedAt,omitempty"`
// A tag associated with a resource.
Tags map[string]*string `json:"tags,omitempty"`
}
The ScraperDescription structure contains the full details about one scraper in your account.
func (*ScraperDescription) DeepCopy ¶ added in v1.2.18
func (in *ScraperDescription) DeepCopy() *ScraperDescription
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ScraperDescription.
func (*ScraperDescription) DeepCopyInto ¶ added in v1.2.18
func (in *ScraperDescription) DeepCopyInto(out *ScraperDescription)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ScraperStatusCode ¶ added in v1.2.18
type ScraperStatusCode string
const ( ScraperStatusCode_CREATING ScraperStatusCode = "CREATING" ScraperStatusCode_UPDATING ScraperStatusCode = "UPDATING" ScraperStatusCode_ACTIVE ScraperStatusCode = "ACTIVE" ScraperStatusCode_DELETING ScraperStatusCode = "DELETING" ScraperStatusCode_CREATION_FAILED ScraperStatusCode = "CREATION_FAILED" ScraperStatusCode_UPDATE_FAILED ScraperStatusCode = "UPDATE_FAILED" ScraperStatusCode_DELETION_FAILED ScraperStatusCode = "DELETION_FAILED" )
type ScraperSummary ¶ added in v1.2.18
type ScraperSummary struct {
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
LastModifiedAt *metav1.Time `json:"lastModifiedAt,omitempty"`
// A tag associated with a resource.
Tags map[string]*string `json:"tags,omitempty"`
}
The ScraperSummary structure contains a summary of the details about one scraper in your account.
func (*ScraperSummary) DeepCopy ¶ added in v1.2.18
func (in *ScraperSummary) DeepCopy() *ScraperSummary
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ScraperSummary.
func (*ScraperSummary) DeepCopyInto ¶ added in v1.2.18
func (in *ScraperSummary) DeepCopyInto(out *ScraperSummary)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ValidationExceptionField ¶ added in v0.0.2
type ValidationExceptionField struct {
Message *string `json:"message,omitempty"`
Name *string `json:"name,omitempty"`
}
Information about a field passed into a request that resulted in an exception.
func (*ValidationExceptionField) DeepCopy ¶ added in v0.0.2
func (in *ValidationExceptionField) DeepCopy() *ValidationExceptionField
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ValidationExceptionField.
func (*ValidationExceptionField) DeepCopyInto ¶ added in v0.0.2
func (in *ValidationExceptionField) DeepCopyInto(out *ValidationExceptionField)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ValidationExceptionReason ¶
type ValidationExceptionReason string
const ( ValidationExceptionReason_UNKNOWN_OPERATION ValidationExceptionReason = "UNKNOWN_OPERATION" ValidationExceptionReason_CANNOT_PARSE ValidationExceptionReason = "CANNOT_PARSE" ValidationExceptionReason_FIELD_VALIDATION_FAILED ValidationExceptionReason = "FIELD_VALIDATION_FAILED" ValidationExceptionReason_OTHER ValidationExceptionReason = "OTHER" )
type Workspace ¶
type Workspace struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec WorkspaceSpec `json:"spec,omitempty"`
Status WorkspaceStatus `json:"status,omitempty"`
}
Workspace is the Schema for the Workspaces API +kubebuilder:object:root=true +kubebuilder:subresource:status +kubebuilder:printcolumn:name="ALIAS",type=string,priority=0,JSONPath=`.spec.alias`
func (*Workspace) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Workspace.
func (*Workspace) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Workspace) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type WorkspaceDescription ¶
type WorkspaceDescription struct {
// A user-assigned workspace alias.
Alias *string `json:"alias,omitempty"`
// An ARN identifying a Workspace.
ARN *string `json:"arn,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
// A KMS Key ARN.
KMSKeyARN *string `json:"kmsKeyARN,omitempty"`
PrometheusEndpoint *string `json:"prometheusEndpoint,omitempty"`
// The status of the workspace.
Status *WorkspaceStatus_SDK `json:"status,omitempty"`
// A tag associated with a resource.
Tags map[string]*string `json:"tags,omitempty"`
// A workspace ID.
WorkspaceID *string `json:"workspaceID,omitempty"`
}
The full details about one Amazon Managed Service for Prometheus workspace in your account.
func (*WorkspaceDescription) DeepCopy ¶
func (in *WorkspaceDescription) DeepCopy() *WorkspaceDescription
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkspaceDescription.
func (*WorkspaceDescription) DeepCopyInto ¶
func (in *WorkspaceDescription) DeepCopyInto(out *WorkspaceDescription)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkspaceList ¶
type WorkspaceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Workspace `json:"items"`
}
WorkspaceList contains a list of Workspace +kubebuilder:object:root=true
func (*WorkspaceList) DeepCopy ¶
func (in *WorkspaceList) DeepCopy() *WorkspaceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkspaceList.
func (*WorkspaceList) DeepCopyInto ¶
func (in *WorkspaceList) DeepCopyInto(out *WorkspaceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WorkspaceList) DeepCopyObject ¶
func (in *WorkspaceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type WorkspaceSpec ¶
type WorkspaceSpec struct {
// An alias that you assign to this workspace to help you identify it. It does
// not need to be unique.
//
// Blank spaces at the beginning or end of the alias that you specify will be
// trimmed from the value used.
Alias *string `json:"alias,omitempty"`
// The list of tag keys and values to associate with the workspace.
Tags map[string]*string `json:"tags,omitempty"`
}
WorkspaceSpec defines the desired state of Workspace.
func (*WorkspaceSpec) DeepCopy ¶
func (in *WorkspaceSpec) DeepCopy() *WorkspaceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkspaceSpec.
func (*WorkspaceSpec) DeepCopyInto ¶
func (in *WorkspaceSpec) DeepCopyInto(out *WorkspaceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkspaceStatus ¶
type WorkspaceStatus struct {
// All CRs managed by ACK have a common `Status.ACKResourceMetadata` member
// that is used to contain resource sync state, account ownership,
// constructed ARN for the resource
// +kubebuilder:validation:Optional
ACKResourceMetadata *ackv1alpha1.ResourceMetadata `json:"ackResourceMetadata"`
// All CRs managed by ACK have a common `Status.Conditions` member that
// contains a collection of `ackv1alpha1.Condition` objects that describe
// the various terminal states of the CR and its backend AWS service API
// resource
// +kubebuilder:validation:Optional
Conditions []*ackv1alpha1.Condition `json:"conditions"`
// The current status of the new workspace. Immediately after you create the
// workspace, the status is usually CREATING.
// +kubebuilder:validation:Optional
Status *WorkspaceStatus_SDK `json:"status,omitempty"`
// The unique ID for the new workspace.
//
// Regex Pattern: `[0-9A-Za-z][-.0-9A-Z_a-z]*`
// +kubebuilder:validation:Optional
WorkspaceID *string `json:"workspaceID,omitempty"`
}
WorkspaceStatus defines the observed state of Workspace
func (*WorkspaceStatus) DeepCopy ¶
func (in *WorkspaceStatus) DeepCopy() *WorkspaceStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkspaceStatus.
func (*WorkspaceStatus) DeepCopyInto ¶
func (in *WorkspaceStatus) DeepCopyInto(out *WorkspaceStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkspaceStatusCode ¶
type WorkspaceStatusCode string
const ( WorkspaceStatusCode_CREATING WorkspaceStatusCode = "CREATING" WorkspaceStatusCode_ACTIVE WorkspaceStatusCode = "ACTIVE" WorkspaceStatusCode_UPDATING WorkspaceStatusCode = "UPDATING" WorkspaceStatusCode_DELETING WorkspaceStatusCode = "DELETING" WorkspaceStatusCode_CREATION_FAILED WorkspaceStatusCode = "CREATION_FAILED" )
type WorkspaceStatus_SDK ¶
type WorkspaceStatus_SDK struct {
// State of a workspace.
StatusCode *string `json:"statusCode,omitempty"`
}
The status of the workspace.
func (*WorkspaceStatus_SDK) DeepCopy ¶
func (in *WorkspaceStatus_SDK) DeepCopy() *WorkspaceStatus_SDK
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkspaceStatus_SDK.
func (*WorkspaceStatus_SDK) DeepCopyInto ¶
func (in *WorkspaceStatus_SDK) DeepCopyInto(out *WorkspaceStatus_SDK)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkspaceSummary ¶
type WorkspaceSummary struct {
// A user-assigned workspace alias.
Alias *string `json:"alias,omitempty"`
// An ARN identifying a Workspace.
ARN *string `json:"arn,omitempty"`
CreatedAt *metav1.Time `json:"createdAt,omitempty"`
// A KMS Key ARN.
KMSKeyARN *string `json:"kmsKeyARN,omitempty"`
// The status of the workspace.
Status *WorkspaceStatus_SDK `json:"status,omitempty"`
// A tag associated with a resource.
Tags map[string]*string `json:"tags,omitempty"`
// A workspace ID.
WorkspaceID *string `json:"workspaceID,omitempty"`
}
The information about one Amazon Managed Service for Prometheus workspace in your account.
func (*WorkspaceSummary) DeepCopy ¶
func (in *WorkspaceSummary) DeepCopy() *WorkspaceSummary
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkspaceSummary.
func (*WorkspaceSummary) DeepCopyInto ¶
func (in *WorkspaceSummary) DeepCopyInto(out *WorkspaceSummary)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.